Trait esp32_simple::infra::Poller

source ·
pub trait Poller {
    // Required method
    fn poll(&mut self) -> Result<!>;
}
A trait representing a poller that performs periodic tasks.

Errors

This trait’s poll method returns an error if the polling operation fails.

Required Methods

source

fn poll(&mut self) -> Result<!>

Polls for periodic tasks.

Errors

Returns an error if the polling operation fails.

Implementors

source

impl<T, MODE, TR> Poller for Button<'_, T, MODE, TR>
where T: InputPin, MODE: InputMode, TR: Trigger,

source

impl<T: Trigger> Poller for Scanner<'_, T>

source

impl<T: Trigger> Poller for Sensor<'_, T>