Trait esp32_simple::infra::Poller
source · pub trait Poller {
// Required method
fn poll(&mut self) -> Result<!>;
}Expand description
A trait representing a poller that performs periodic tasks.
Errors
This trait’s poll method returns an error if the polling operation fails.